@@ -83,6 +83,19 @@ setSDMXServiceProviders <- function(){ # nocov start
       repoUrl = "http://ec.europa.eu/eurostat/SDMX/diss-web/rest",
       compliant = TRUE)
   )
+  ESTAT@builder@handler$dataflow = function(obj){
+    if(is.null(obj@resourceId)) obj@resourceId = "all"
+    if(is.null(obj@version)) obj@version = "latest"
+    req <- sprintf("%s/dataflow/ESTAT/%s/%s/",obj@regUrl, obj@resourceId, obj@version)        
+    return(req)
+  }
+  ESTAT@builder@handler$datastructure = function(obj){
+    if(is.null(obj@resourceId)) obj@resourceId = "all"
+    if(is.null(obj@version)) obj@version = "latest"
+    req <- sprintf("%s/datastructure/ESTAT/%s/%s/",obj@regUrl, obj@resourceId, obj@version)
+    req <- paste0(req, "?references=children") #TODO to see later to have arg for this
+    return(req)
+  }
   
   #IMF
   IMF <- SDMXServiceProvider(
@@ -173,6 +186,16 @@ setSDMXServiceProviders <- function(){ # nocov start
       repoUrl = "http://data.uis.unesco.org/RestSDMX/sdmx.ashx")
   )
   
+  #WBG_WITS (World Integrated Trade Solution)
+  WBG_WITS <- SDMXServiceProvider(
+    agencyId = "WBG_WITS", name = "World Integrated Trade Solution",
+    builder = SDMXREST21RequestBuilder(
+      regUrl = "http://wits.worldbank.org/API/V1/SDMX/V21/rest",
+      repoUrl = "http://wits.worldbank.org/API/V1/SDMX/V21/rest",
+      compliant = TRUE, skipProviderId = TRUE
+    )
+  )
+  
   #national data providers
   #-----------------------
   
@@ -228,7 +251,7 @@ setSDMXServiceProviders <- function(){ # nocov start
     builder = SDMXREST21RequestBuilder(
       regUrl = "http://sdmx.istat.it/SDMXWS/rest",
       repoUrl = "http://sdmx.istat.it/SDMXWS/rest",
-      compliant = TRUE, unsupportedResources = list("datastructure")
+      compliant = TRUE
     )
   )
   
@@ -283,7 +306,7 @@ setSDMXServiceProviders <- function(){ # nocov start
   
   listOfProviders <- list(
     #international
-    ECB,ESTAT,IMF,OECD,UNSD,FAO,ILO,UIS,
+    ECB,ESTAT,IMF,OECD,UNSD,FAO,ILO,UIS,WBG_WITS,
     #national
     ABS,NBB,INSEE,INEGI,ISTAT,
     #others
